function createSnake(color, keys)
local	snake = {}
	snake.oldDirection = {}
	snake.canvas = love.graphics.newCanvas(map.width*17, map.height*17)
	snake.keytimer = 0.15
	snake.x = math.random(map.width)
	snake.y = math.random(map.height)
	snake.length = 4
	snake.direction = {-1, 0}
	snake.timer = 0
	snake.tongue = false
	snake.update = function(self, dt)
		self.timer = self.timer + dt
		self.keytimer = self.keytimer + dt
		if self.timer > 0.2 then
			if self.direction[2] == 0 then
				self.angle = math.pi/2 * self.direction[1] * -1
			elseif self.direction[1] == 0 then
				self.angle = math.pi/2 * self.direction[2] - math.pi/2
			end
			self.tongue = not self.tongue
			self.oldDirection[1], self.oldDirection[2] = self.direction[1], self.direction[2]
			table.insert(self.squares, {self.x, self.y})
			self.x = self.x + self.direction[1]
			self.y = self.y + self.direction[2]
			if self.x > map.width then
				self.x = 1
			elseif self.x < 1 then
				self.x = map.width
			end
			if self.y > map.height then
				self.y = 1
			elseif self.y < 1 then
				self.y = map.height
			end
			self.timer = self.timer - 0.1
			self.colliding = self.colliding or false
			for i, v in ipairs(self.squares) do
				snake.colliding = (v[1] == self.x and v[2] == self.y) or snake.colliding
			end
			if #self.squares > self.length then
				table.remove(self.squares, 1)
			end
			--Canvas drawing
			self.canvas:clear()
			love.graphics.setCanvas(self.canvas)
			for i, v in ipairs(self.squares) do
				if cfg[9] then
					local alpha = (i/#self.squares)*cfg[10] + 255-cfg[10]
					love.graphics.setColor(255,255,255,alpha)
				end
				love.graphics.draw(snake.squares['#'], (v[1]-1)*17+1, (v[2]-1)*17+1)
			end
			if cfg[8] then
				love.graphics.draw(self.squares[self.tongue], (self.x-self.direction[1])*17-8, (self.y-self.direction[2])*17-8, self.angle, 1, 1, 8, 8)
			end
			love.graphics.setColor(255,255,255)
			love.graphics.setCanvas()
			--
		end
	end
	snake.squares = {{snake.x, snake.y}}
	snake.squares['#'] = love.image.newImageData(16, 16)
	snake.squares['#']:mapPixel(function() return color[1] or 0, color[2] or 192, color[3] or 0, color[4] or 255 end)
	snake.squares['#'] = love.graphics.newImage(snake.squares['#'])
	snake.squares[false] = love.graphics.newImage('img/face.png')
	snake.squares[true] = love.graphics.newImage('img/face_tongue.png')
	setmetatable(snake.squares, {__index = function() return {-5, -5} end})
	snake.draw = function(self)
		love.graphics.draw(self.canvas, 0, 0)
	end
	
	snake.keypressed = function(self, key, unicode)
		if key == keys.up and self.direction[2] ~= 1 and self.oldDirection[2] ~= 1 then
			self.direction = {0, -1}
		elseif key == keys.down and self.direction[2] ~= -1 and self.oldDirection[2] ~= -1 then
			self.direction = {0, 1}
		elseif key == keys.right and self.direction[1] ~= -1 and self.oldDirection[1] ~= -1 then
			self.direction = {1, 0}
		elseif key == keys.left and self.direction[1] ~= 1 and self.oldDirection[1] ~= 1 then
			self.direction = {-1, 0}
		end
	end
	
	return snake
end


return createSnake